intervals_list = [
    {  
        'name': 'Perfect unison',
        'semitones': 0,
        'short': 'P1'
    },
    {  
        'name': 'Minor second',
        'semitones': 1,
        'short': 'm2'
    },
    {  
        'name': 'Major second',
        'semitones': 2,
        'short': 'M2'
    },
    {  
        'name': 'Minor third',
        'semitones': 3,
        'short': 'm3'
    },
    {  
        'name': 'Major third',
        'semitones': 4,
        'short': 'M3'
    },
    {  
        'name': 'Perfect fourth',
        'semitones': 5,
        'short': 'P4'
    },
    {  
        'name': 'Tritone',
        'semitones': 6,
        'short': 'TT'
    },
    {  
        'name': 'Perfect fifth',
        'semitones': 7,
        'short': 'P5'
    },
    {  
        'name': 'Minor sixth',
        'semitones': 8,
        'short': 'm6'
    },
    {  
        'name': 'Major sixth',
        'semitones': 9,
        'short': 'M6'
    },
    {  
        'name': 'Minor seventh',
        'semitones': 10,
        'short': 'm7'
    },
    {  
        'name': 'Major seventh',
        'semitones': 11,
        'short': 'M7'
    },
    {  
        'name': 'Octave',
        'semitones': 12,
        'short': 'P8'
    }
]



from setuptools import setup, find_packages

setup(
    name="pysongtool",
    version="0.10.5",
    author="Murilo R.B Silva",
    description="A Python library that gives musical theory contend.",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/MuriloRyan/pysongtool",  # Substitua com o link do seu repositório
    packages=find_packages(),
    install_requires=[
        "iniconfig==2.0.0",
        "packaging==24.2",
        "pluggy==1.5.0",
        "pytest==8.3.3",
        "setuptools==75.6.0"
    ],
    python_requires=">=3.7",
    classifiers=[
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Software Development :: Libraries",
        "Topic :: Multimedia :: Sound/Audio :: Analysis",
    ],
    keywords="music theory scales chords intervals",
    license="MIT"
)
